<?php
namespace Teknisa\MAN\Services;

use Doctrine\DBAL\Connection;
use Doctrine\ORM\EntityManager;

class TabelaPreco{
    
    protected $conn;
    protected $entityManager;
    
    public function __construct(Connection $conn, EntityManager $entityManager) {
        $this->conn = $conn;
        $this->entityManager = $entityManager;
    }
    

  
    public function getCdGrupoProd($CDFILIAL, $NRORG){
        $params = array(
            ':P_CDFILIAL'    =>  $CDFILIAL,
            ':P_NRORG'      =>  $NRORG
        );
        
        $result = $this->conn->fetchAll(self::GET_CDGRUPPROD,$params);
        if(count($result)>0)
            return $result[0]['CDGRPRODPDV'];
        else
        return null;
        
    }
    
    public function getNrConfig($CDFILIAL,$CDGRPRODPDV, $NRORG){
        
        $params = array(
            ':P_CDFILISUBGR'    =>  $CDFILIAL,
            ':P_CDGRUPPROD'     =>  $CDGRPRODPDV,
            ':P_NRORG'          =>  $NRORG
        );
        
        $result = $this->conn->fetchAll(self::GET_NRCONFIG,$params);
        
        return $result;
    }
    
    public function findVigenciasImport($params){
        $CDFILIAL      = $params[0]['value'];
        $P_CDTABEPREC  = $params[1]['value'];
        $P_DTINIVGPREC = $params[2]['value'];
        
        $params = array(
            ':P_CDFILIAL'    =>  $CDFILIAL,
            ':P_CDTABEPREC'  =>  $P_CDTABEPREC,
            ':P_DTINIVGPREC' =>   $P_DTINIVGPREC
            
        );
        
        $result = $this->conn->fetchAll(self::GET_VIGENCIA_BYTABELAPRECO_BYFILIAL,$params);
        return $result;
    }
    
    public function validImportPriceChart($params){
        $CDFILIAL          = $params[0]['value'];
        $P_CDTABEPREC      = $params[1]['value'];
        $P_DTINIVGPRECORIG = substr($params[2]['value'], 3,10);
        $P_DTINIVGPRECDEST = $params[3]['value'];
        
        if($P_DTINIVGPRECORIG == ""){
            throw new \Exception('EMPTYFIELD',1);
        }
        
        $params = array(
            ':P_CDFILIAL'    =>  $CDFILIAL,
            ':P_CDTABEPREC'  =>  $P_CDTABEPREC,
            ':P_DTINIVGPREC' =>   $P_DTINIVGPRECORIG
            
        );
        $resultOri = $this->conn->fetchAll(self::CHECK_PRECO_VIGENCIA_EXISTS,$params);
        

        $params = array(
            ':P_CDFILIAL'    =>  $CDFILIAL,
            ':P_CDTABEPREC'  =>  $P_CDTABEPREC,
            ':P_DTINIVGPREC' =>   $P_DTINIVGPRECDEST
            
        );
        $resultDest = $this->conn->fetchAll(self::CHECK_PRECO_VIGENCIA_EXISTS,$params);
        return $resultDest;
    }
    
    public function importItensVigencia($params){
        $P_CDFILIAL        = $params[0]['value'];
        $P_CDTABEPREC      = $params[1]['value'];
        $P_DTINIVGPRECORIG = substr($params[2]['value'], 3,10);
        $P_DTINIVGPRECDEST = $params[3]['value'];
        $P_DTFINVGPRECDEST = $params[4]['value'];
        $ISPOPULADA        = $params[5]['value'];
        if($ISPOPULADA == "S"){
            $paramsDelete = array(
                ':P_CDFILIAL'    =>  $P_CDFILIAL,
                ':P_CDTABEPREC'  =>  $P_CDTABEPREC,
                ':P_DTINIVGPREC' =>  $P_DTINIVGPRECDEST
            );
            $this->conn->executeQuery(self::DELETE_ITEM_VIGENCIADES_1,$paramsDelete);
            $this->conn->executeQuery(self::DELETE_ITEM_VIGENCIADES_2,$paramsDelete);
        }
        
        $paramsInsertPreco = array(
            ':P_CDFILIAL'    =>  $P_CDFILIAL,
            ':P_CDTABEPREC'  =>  $P_CDTABEPREC,
            ':P_DTINIVGDEST' =>  $P_DTINIVGPRECDEST,
            ':P_DTINIVGORIG' =>  $P_DTINIVGPRECORIG
        );
        $this->conn->executeQuery(self::INSERT_ITEM_VIGENCIADES_1,$paramsInsertPreco);
        
        $paramsInsertPrecoVenda = array(
            ':P_CDFILIAL'    =>  $P_CDFILIAL,
            ':P_CDTABEPREC'  =>  $P_CDTABEPREC,
            ':P_DTINIVGDEST' =>  $P_DTINIVGPRECDEST,
            ':P_DTFINVGDEST' =>  $P_DTFINVGPRECDEST,
            ':P_DTINIVGORIG' =>  $P_DTINIVGPRECORIG
        );
        $this->conn->executeQuery(self::INSERT_ITEM_VIGENCIADES_2,$paramsInsertPrecoVenda);
    }

    public function getCdSegmer($CDFILIAL, $NRORG) {
        $params = array(
            ':P_CDFILIAL'   => $CDFILIAL,
            ':P_NRORG'   => $NRORG
        );
        $result = $this->conn->fetchAll(self::GET_CDSEGMER, $params);
        return (empty($result[0]) ? null : $result[0]['CDSEGMER']);
    }
    
    public function insertTabelaPreco($CDFILIAL,$CDTABEPREC,$NMTABEPREC,$IDATIVO,$CDOPERULTATU,$DTULTATU,$NRORGULTATU,$CDOPERINCLUSAO,$DTINCLUSAO,$NRORG,$NRORGINCLUSAO){

       $params = array(
            'CDFILIAL'          =>  $CDFILIAL,
            'CDTABEPREC'        =>  $CDTABEPREC,
            'NMTABEPREC'        =>  $NMTABEPREC,
            'IDATIVO'           =>  $IDATIVO,
            'CDOPERULTATU'      =>  $CDOPERULTATU,
            'DTULTATU'          =>  $DTULTATU,
            'NRORGULTATU'       =>  $NRORGULTATU,
            'CDOPERINCLUSAO'    =>  $CDOPERINCLUSAO,
            'DTINCLUSAO'        =>  $DTINCLUSAO,
            'NRORG'             =>  $NRORG,
            'NRORGINCLUSAO'     =>  $NRORGINCLUSAO
        ); 
        
        $result = $this->conn->executeQuery(self::INSERT_TABEPREC,$params);
    
    }
    
    public function updateTABEPREC($CDFILIAL,$NMTABEPREC,$NRORG,$CDOPERULTATU,$DTULTATU,$NRORGULTATU,$CDTABEPREC){
        $params = array(
            'NRORG'         =>  $NRORG,
            'CDTABEPREC'    =>  $CDTABEPREC,
            'CDOPERULTATU'  =>  $CDOPERULTATU,
            'NMTABEPREC'   => $NMTABEPREC,
            '$DTULTATU'     => $DTULTATU,
            'NRORGULTATU'   => $NRORGULTATU,
            'CDFILIAL'      => $CDFILIAL
        );
        
        $result = $this->conn->executeQuery(self::UPDATE_TABEPREC,$params);
    }
    
    public function insertPrecoItem($params,$data){
        $this->entityManager->getConnection()->beginTransaction();
        try{
            $i = 0;
            foreach ($data as $value) {
                if($value['CDARVPROD'] >= $params['CDPRODUTOINI'] && $value['CDARVPROD'] <= $params['CDPRODUTOFIN'] ){
                    $params = array_merge($params,array(
                        'CDPRODUTO'         =>  $value['CDPRODUTO'],
                        'CDPRPAITABPR'      =>  (isset($value['CDPRPAITABPR']) ? $value['CDPRPAITABPR'] : $value['CDPRODUTO'])
                    ));
                    $result = $this->conn->executeQuery(self::INSERT_ITEMPRECO,$params);
                    $i++;
                }
            }
            $this->entityManager->getConnection()->commit();
            return $i;
        }catch(Exception $e){
            $this->entityManager->getConnection()->rollBack();
            throw $e->getMessage;
        }
    }
    
    public function InsertVigencia($CDFILIAL,$CDTABEPREC,$DTINIVGPREC,$DTFINVGPREC,$CDOPERINCLUSAO,$DTINCLUSAO,$NRORGINCLUSAO,$NRORG,$CDOPERULTATU,$DTULTATU,$NRORGULTATU){
        $params = array(
            ':CDFILIAL'          =>  $CDFILIAL,
            ':CDTABEPREC'        =>  $CDTABEPREC,
            ':DTINIVGPREC'       =>  $DTINIVGPREC,
            ':DTFINVGPREC'       =>  $DTFINVGPREC,
            ':CDOPERINCLUSAO'    =>  $CDOPERINCLUSAO,
            ':DTINCLUSAO'        =>  $DTINCLUSAO,
            ':NRORGINCLUSAO'     =>  $NRORGINCLUSAO,
            ':NRORG'             =>  $NRORG,
            ':CDOPERULTATU'      =>  $CDOPERULTATU,
            ':DTULTATU'          =>  $DTULTATU,
            ':NRORGULTATU'       =>  $NRORGULTATU
        );
        $result = $this->conn->executeQuery(self::INSERT_VIGENCIA,$params);
    }
    
    public function updateVigencia($CDFILIAL,$CDTABEPREC,$DTINIVGPREC,$DTFINVGPREC, $OLD_DTINIVGPREC, $OLD_DTFINVGPREC , $NRORG,$CDOPERULTATU,$DTULTATU,$NRORGULTATU){
        $params = array(
            'CDFILIAL'      =>  $CDFILIAL,
            'CDTABEPREC'    =>  $CDTABEPREC,
            'DTINIVGPREC'   =>  $DTINIVGPREC,
            'DTFINVGPREC'   =>  $DTFINVGPREC,
            'NRORG'         =>  $NRORG,
            'CDOPERULTATU'  =>  $CDOPERULTATU,
            'DTULTATU'      =>  $DTULTATU,
            'NRORGULTATU'   =>  $NRORGULTATU, 
            'OLD_DTINIVGPREC' => $OLD_DTINIVGPREC, 
            'OLD_DTFINVGPREC' => $OLD_DTFINVGPREC
        );
        
        $result = $this->conn->executeQuery(self::UPDATE_VIGENCIA,$params);
    }
    
    public function deleteVigencia($CDFILIAL,$NRORG,$CDTABEPREC,$DTINIVGPREC){
        $params = array(
            ':CDFILIAL'     =>  $CDFILIAL,
            ':NRORG'        =>  $NRORG,
            ':CDTABEPREC'   =>  $CDTABEPREC,
            ':DTINIVGPREC'  =>  $DTINIVGPREC
        );
        
        $result = $this->conn->executeQuery(self::DELETE_TABEVEND,$params);
    }
    
    public function updatePrecoItem($params){
        $this->entityManager->getConnection()->beginTransaction();
        try{
            $result = $this->conn->executeQuery(self::UPDATE_ITEMPRECO,$params);
            $this->entityManager->getConnection()->commit();
        }catch(Exception $e){
            $this->entityManager->getConnection()->rollBack();
            throw $e->getMessage;
        }
    }
    
    public function updatePrecoItemInline($IDPRECVARIA,$VRPRECITEMDLV,$VRPRECITEMCMD,$CDFILIAL,$NRORG,$CDTABEPREC,$DTINIVGPREC,$CDPRODUTO,$VRPRECITEM,$VRCUSTITEM,$VRPRESUGITEM, $VRPRECITEMCL, $IDPRODPROMOC, $HRINIVENPROD, $HRFIMVENPROD){
        $params = array(
            ':IDPRECVARIA'      =>  $IDPRECVARIA,
            ':VRPRECITEMDLV'    =>  $VRPRECITEMDLV,
            ':VRPRECITEMCMD'    =>  $VRPRECITEMCMD,
            ':CDFILIAL'         =>  $CDFILIAL,
            ':NRORG'            =>  $NRORG,
            ':CDTABEPREC'       =>  $CDTABEPREC,
            ':DTINIVGPREC'      =>  $DTINIVGPREC,
            ':CDPRODUTO'        =>  $CDPRODUTO,
            ':VRPRECITEM'       =>  $VRPRECITEM,
            ':VRCUSTITEM'       =>  $VRCUSTITEM,
            ':VRPRESUGITEM'     =>  $VRPRESUGITEM,
            ':VRPRECITEMCL'     =>  $VRPRECITEMCL,
            ':IDPRODPROMOC'     =>  $IDPRODPROMOC,
            ':HRINIVENPROD'     =>  $HRINIVENPROD,
            ':HRFIMVENPROD'     =>  $HRFIMVENPROD
        );
        $result = $this->conn->executeQuery(self::UPDATE_ITEMPRECO_INLINE,$params);
        
    }
    
    
    public function getInsertValidVigenciaDate($CDFILIAL,$CDTABEPREC){
        $params = array(
            ':CDFILIAL'     =>  $CDFILIAL,
            ':CDTABEPREC'   =>  $CDTABEPREC     
        );
        
        return $this->conn->fetchAll(self::GET_VALID_INSERT_VIGDATE,$params);
    }
    
    
    public function updatePrecoDiferenciado($VRPRECODIADLV,$VRPRECODIACMD,$IDTPMODCMD,$IDTPMODDLV,$IDTPMODGERAL,$CDFILIAL,$CDTABEPREC,$DTINIVGPREC,$CDPRODUTO,$CDPRPAITABPR,$NRDIASEMANPR,$HRINIPRECDIA,$HRFINPRECDIA,$VRPRECODIA,$IDPERVALORPR,$IDDESCACREPR,$DTINIVALPREC,$DTFINVALPREC,$CDTIPOCONSPD,$IDVISUACUPOM,$NMTIPOCONS,$NRORG,$CDOPERULTATU,$DTULTATU,$NRORGULTATU,$VRPRECODIF){
        $params = array(
            ':CDFILIAL'      =>  $CDFILIAL,
            ':CDTABEPREC'    =>  $CDTABEPREC,
            ':DTINIVGPREC'   =>  $DTINIVGPREC,
            ':CDPRODUTO'     =>  $CDPRODUTO,
            ':CDPRPAITABPR'  =>  $CDPRPAITABPR,
            ':NRDIASEMANPR'  =>  $NRDIASEMANPR,
            ':HRINIPRECDIA'  =>  $HRINIPRECDIA,
            ':HRFINPRECDIA'  =>  $HRFINPRECDIA,
            ':VRPRECODIA'    =>  $VRPRECODIA,
            ':IDPERVALORPR'  =>  $IDPERVALORPR,
            ':IDDESCACREPR'  =>  $IDDESCACREPR,
            ':DTINIVALPREC'  =>  $DTINIVALPREC,
            ':DTFINVALPREC'  =>  $DTFINVALPREC,
            ':CDTIPOCONSPD'  =>  $CDTIPOCONSPD,
            ':IDVISUACUPOM'  =>  $IDVISUACUPOM,
            ':NMTIPOCONS'    =>  $NMTIPOCONS,
            ':NRORG'         =>  $NRORG,
            ':CDOPERULTATU'  =>  $CDOPERULTATU,
            ':DTULTATU'      =>  $DTULTATU,
            ':NRORGULTATU'   =>  $NRORGULTATU,
            ':VRPRECODIF'    =>  $VRPRECODIF,
            ':VRPRECODIADLV' =>  $VRPRECODIADLV,
            ':VRPRECODIACMD' =>  $VRPRECODIACMD,
            ':IDTPMODGERAL'  =>  $IDTPMODGERAL,
            ':IDTPMODCMD'    =>  $IDTPMODCMD,
            ':IDTPMODDLV'    =>  $IDTPMODDLV
        );
        
        return $this->conn->executeQuery(self::UPDATE_PRECODIFERENCIADO,$params);
    }
    
    
     public function verificaPrecoDifConsumidor($row){
        $return = true;
        $params = array(
            ':CDFILIAL'      =>  $row['CDFILIAL'],
            ':CDTABEPREC'    =>  $row['CDTABEPREC'],
            ':DTINIVGPREC'   =>  $row['DTINIVGPREC'],
            ':CDPRODUTO'     =>  $row['CDPRODUTO'],
            ':CDPRPAITABPR'  =>  $row['CDPRPAITABPR'],
            ':NRDIASEMANPR'  =>  $row['NRDIASEMANPR'],
            ':HRINIPRECDIA'  =>  $row['HRINIPRECDIA'],
            ':DTINIVALPREC'  =>  $row['DTINIVALPREC'],
            ':CDTIPOCONSPD'  =>  $row['CDTIPOCONSPD'],
            ':NRORG'         =>  $row['NRORG']
        );
        
        $dados = $this->conn->fetchAssoc(self::SELECT_PRECODIFERENCIADO,$params);
        if(!empty($dados)){
            if($dados['TOT'] > 0){
                $return = false;
            }else{
                $return = true;
            }
        }else{
            $return = true;
        }
        return $return;
    }
    
    
    public function getUpdateValidVigenciaDate($CDFILIAL,$CDTABEPREC,$DTINIVGPREC,$DTFINVGPREC){
        $params = array(
            ':CDFILIAL'     =>  $CDFILIAL,
            ':CDTABEPREC'   =>  $CDTABEPREC,
            ':DTINIVGPREC'  =>  $DTINIVGPREC,
            ':DTFINVGPREC'  =>  $DTFINVGPREC
        );
        return $this->conn->fetchAll(self::GET_VALID_UPDATE_VIGDATE,$params);
    }
    
    public function isParameterizedBySomething($CDFILIAL,$CDTABEPREC){
        $params = array(
            ':CDFILIAL'     =>  $CDFILIAL,
            ':CDTABEPREC'   =>  $CDTABEPREC
        );
        $result = $this->conn->fetchAll(self::IS_PARAMETERIZED_BY_CLIENTEFILIAL,$params);
        if(count($result) > 0)
            return 1;
        $result = $this->conn->fetchAll(self::IS_PARAMETERIZED_BY_LOJA,$params);
        if(count($result) > 0)
            return 2;
        $result = $this->conn->fetchAll(self::IS_PARAMETERIZED_BY_FILIAL,$params);
        if(count($result) > 0)
            return 3;
        $result = $this->conn->fetchAll(self::IS_PARAMETERIZED_BY_CLIENTE,$params);
        if(count($result) > 0)
            return 4;
        else return false;
    }
    
    public function updatePrecoItemInlinePrecoDiferenciado($params){
        $result = $this->conn->executeQuery(self::UPDATE_ITEMPRECO_INLINE_PRECODIFERENCIADO,$params);
    }
    
    public function updItemPrecoAtuPrec($params) {
        $result = $this->conn->executeQuery(self::updItemPrecoAtuPrec,$params);
        return $result;
    }
    
    public function adqParamVend($params) {
        $result = $this->conn->fetchAll(self::adqParamVend,$params);
        return $result;
    }
    
    public function adqModProduto($params) {
        $result = $this->conn->fetchAll(self::adqModProduto,$params);
        return $result;
    }
    
    public function adqPadraoLocal($params) {
        $result = $this->conn->fetchAll(self::adqPadraoLocal,$params);
        return $result;
    }
    
    public function adqAuxFilial($params) {
        $result = $this->conn->fetchAll(self::adqAuxFilial,$params);
        return $result;
    }
    
    public function adqItemPreco($params) {
        $result = $this->conn->fetchAll(self::adqItemPreco,$params);
        return $result;
    }
    
    public function getIntervaloCadastroAutomatico($params) {
        $result = $this->conn->fetchAll(self::GET_INTERVALO_CAD_AUTOMATICO, $params);
        return $result;
    }
    
    public function setPrecoAutomatico($params) {
        $result = $this->conn->executeQuery(self::SET_PRECO_AUTOMATICO, $params);
        return $result;
    }
    
    public function deletePreco($params) {
        $this->conn->executeQuery(self::DELETE_PRECO, $params);
    }
    
    public function deletePrecosDiferenciados($params) {
        $this->conn->executeQuery(self::DELETE_PRECOS_DIFERENCIADOS, $params);
    }
    
    public function manutencaoPrecos($params) {
        $this->entityManager->getConnection()->beginTransaction();
        $log = 'Iniciando Operação'.PHP_EOL.
                'Data: '.$params[0]['INCLUSAODT'].PHP_EOL.
                'Operador: '.$params[0]['CDOPERINCLUSAO'].PHP_EOL.
                '------------------------------------------------'.PHP_EOL;
        try{
	       foreach ($params as $row) {
	            $paramsQuery = array(
	                ':PRECO'        => $row['PRECO'],
	                ':NRORG'        => $row['NRORG'],
                    ':CDFILIAL'     => $row['CDFILIAL'],
                    ':CDTABEPREC'   => $row['CDTABEPREC'],
                    ':CDPRODUTO'    => $row['CDPRODUTO']
                );
                $vrProdAnt = $this->conn->fetchAssoc(self::SELECT_PRECO_ANTIGO, $paramsQuery);
                $vrProdAnt = $vrProdAnt['VRPRECITEM'];
                if ($vrProdAnt != '' && $vrProdAnt != null) {
                    $paramsQueryHistorico = array(
    	                ':PRECO'          => $row['PRECO'],
    	                ':NRORG'          => $row['NRORGBACK'],
                        ':CDFILIAL'       => $row['CDFILIAL'],
                        ':CDTABEPREC'     => $row['CDTABEPREC'],
                        ':CDPRODUTO'      => $row['CDPRODUTO'],
                        ':VRPROTANT'      => $vrProdAnt,
                        ':NRORGINCLUSAO'  => $row['NRORGINCLUSAO'],
    	                ':CDOPERULTATU'   => $row['CDOPERULTATU'],
                        ':CDOPERINCLUSAO' => $row['CDOPERINCLUSAO'],
                        ':DTULTATU'       => $row['DTULTATU'],
                        ':INCLUSAODT'     => $row['INCLUSAODT'],
                        ':DTALTERACAO'    => $row['DTALTERACAO'],
                        ':NRORGULTATU'    => $row['NRORGULTATU'],
                        ':CDOPERADOR'     => $row['CDOPERADOR']
                    );
                    $this->conn->executeQuery(self::INSERT_TABEULTPREC, $paramsQueryHistorico);
    	            $this->conn->executeQuery(self::UPDATE_PRECO_ITEM, $paramsQuery);
    	            $log.= ' < '.$row['CDPRODUTO'].' - '.$row['DSPRODEMIS'].' > '.' < '.'Valor Antigo: '.$vrProdAnt.' > '.' < '.'Valor Atual: '.$row['PRECO'].' > '.PHP_EOL;
                }
	       }
	       $this->entityManager->getConnection()->commit();
	       return $log;
	   } catch (Exception $e){
	       $this->entityManager->getConnection()->rollBack();
	       throw $e;
	   }
    }
    
    public function verificaPrecoDoProduto($params) {
        $result = $this->conn->fetchAll(self::SELECT_PRECO_PRODUTO, $params);
        return $result[0]['VRPRECITEM'];
    }
    
    public function getValorDiferenciado($params) {
        $result = $this->conn->fetchAll(self::GET_VALORES_DIFERENCIADOS, $params);
        return $result;
    }
    
    const DELETE_PRECO = "
        DELETE FROM ITEMPRECO
        WHERE
            NRORG =             :NRORG
            AND   CDFILIAL    = :CDFILIAL
            AND   CDTABEPREC  = :CDTABEPREC
            AND   CDPRODUTO   = :CDPRODUTO
            AND   DTINIVGPREC = :DTINIVGPREC
    ";
    
    const DELETE_PRECOS_DIFERENCIADOS = "
        DELETE FROM ITEMPRECODIA
        WHERE
            NRORG =             :NRORG
            AND   CDFILIAL    = :CDFILIAL
            AND   CDTABEPREC  = :CDTABEPREC
            AND   CDPRODUTO   = :CDPRODUTO
            AND   DTINIVGPREC = :DTINIVGPREC
    ";
    
    const GET_CDGRUPPROD = "
  	SELECT
     PV.CDGRPRODPDV,
     GP.CDGRUPPROD||' - '||GP.NMGRUPPROD AS GRUPOPROD
    FROM
       PARAVEND PV, GRUPPROD GP
    WHERE
       (PV.CDFILIAL    = :P_CDFILIAL  ) AND
       (PV.NRORG       = :P_NRORG) AND
       (PV.NRORG       = GP.NRORG) AND
       (PV.CDGRPRODPDV = GP.CDGRUPPROD)
	";
	
	const GET_NRCONFIG = "
    	SELECT NRCONFIG
	    	FROM
	    	(SELECT
	       		COUNT(*) AS NRCONFIG
	    	  FROM PRSUBGRPROD
		    WHERE
		       (CDFILISUBGR = :P_CDFILISUBGR) AND
		       (CDGRUPPROD  = :P_CDGRUPPROD ) AND
		       (NRORG       = :P_NRORG)
		   	)
    ";//CDFILIAL CDGRPRODPDV
    
    const GET_VIGENCIA_BYTABELAPRECO_BYFILIAL = "
    SELECT DTINIVGPREC, DTFINVGPREC, 
    'De ' || TO_CHAR(DTINIVGPREC, 'DD/MM/YYYY') || ' até ' || TO_CHAR(DTFINVGPREC, 'DD/MM/YYYY') DTVGPRECLABEL,
      CASE 
       WHEN DTINIVGPREC IS NULL 
        THEN 'Sem Vigência' 
       WHEN SYSDATE BETWEEN DTINIVGPREC AND DTFINVGPREC 
        THEN 'Ativa' 
       ELSE 'Inativa'  
      END AS STATUS_VIGENCIA
    FROM TABEVEND
    WHERE (CDFILIAL     =  :P_CDFILIAL)   AND
          (CDTABEPREC   =  :P_CDTABEPREC) AND
          (DTINIVGPREC  <> :P_DTINIVGPREC )
    ORDER BY DTINIVGPREC
  ";
  
  const CHECK_PRECO_VIGENCIA_EXISTS = "
    SELECT CDFILIAL
      FROM ITEMPRECO
      WHERE (CDFILIAL    = :P_CDFILIAL)   AND
            (CDTABEPREC  = :P_CDTABEPREC) AND
            (DTINIVGPREC = :P_DTINIVGPREC)
      UNION
      SELECT CDFILIAL
      FROM ITEMPRECOCLI
      WHERE (CDFILIAL    = :P_CDFILIAL)   AND
            (CDTABEPREC  = :P_CDTABEPREC) AND
            (DTINIVGPREC = :P_DTINIVGPREC)
      UNION
      SELECT CDFILIAL
      FROM ITEMPRECOCON
      WHERE (CDFILIAL    = :P_CDFILIAL)   AND
            (CDTABEPREC  = :P_CDTABEPREC) AND
            (DTINIVGPREC = :P_DTINIVGPREC)
  ";
  
  const DELETE_ITEM_VIGENCIADES_1 = "
    DELETE
      FROM ITEMPRECODIA
     WHERE (CDFILIAL    = :P_CDFILIAL   )
       AND (CDTABEPREC  = :P_CDTABEPREC )
       AND (DTINIVGPREC = :P_DTINIVGPREC)
  " ;
  
  const DELETE_ITEM_VIGENCIADES_2 = "
    DELETE
      FROM ITEMPRECO
      WHERE (CDFILIAL    = :P_CDFILIAL)   
        AND (CDTABEPREC  = :P_CDTABEPREC) 
        AND (DTINIVGPREC = :P_DTINIVGPREC)
  ";
  
  const INSERT_ITEM_VIGENCIADES_1 = "
    INSERT INTO ITEMPRECO
      (CDFILIAL, CDTABEPREC, DTINIVGPREC, CDPRODUTO, CDPRPAITABPR,
       VRPRECITEM, VRPRECITEMCL)
      (SELECT CDFILIAL, CDTABEPREC, :P_DTINIVGDEST, CDPRODUTO, CDPRPAITABPR,
              VRPRECITEM, VRPRECITEMCL
       FROM ITEMPRECO
       WHERE (CDFILIAL    = :P_CDFILIAL)   AND
             (CDTABEPREC  = :P_CDTABEPREC) AND
             (DTINIVGPREC = :P_DTINIVGORIG))
  " ;
  
  const INSERT_ITEM_VIGENCIADES_2 = "
    INSERT INTO ITEMPRECODIA
     (CDFILIAL, CDTABEPREC, DTINIVGPREC, DTINIVALPREC, DTFINVALPREC, CDPRODUTO, CDPRPAITABPR,
      NRDIASEMANPR, HRINIPRECDIA, HRFINPRECDIA, VRPRECODIA, IDPERVALORPR, IDDESCACREPR, CDTIPOCONSPD)
    SELECT
       CDFILIAL, CDTABEPREC, :P_DTINIVGDEST, :P_DTINIVGDEST, :P_DTFINVGDEST, CDPRODUTO, CDPRPAITABPR,
       NRDIASEMANPR, HRINIPRECDIA, HRFINPRECDIA, VRPRECODIA, IDPERVALORPR, IDDESCACREPR, CDTIPOCONSPD
    FROM
       ITEMPRECODIA
    WHERE
       (CDFILIAL    = :P_CDFILIAL   ) AND
       (CDTABEPREC  = :P_CDTABEPREC ) AND
       (DTINIVGPREC = :P_DTINIVGORIG)
      ";
      
      const GET_CDSEGMER = "
		SELECT DISTINCT
		   FI.CDFILIAL  , FI.NMFILIAL, FI.CDSEGMER, FI.CDEMPRESA,
		   FI.CDINSCESTA, E.CDPAIS   , E.SGESTADO , E.CDMUNICIPIO,
		   SE.CDSEGMER||' - '||SE.DSSEGMER AS SEGMENTO,
		   PA.IDPRECDIFCOM
		FROM
		   FILIAL FI
       LEFT JOIN SEGMERCADO SE ON
        (FI.CDSEGMER = SE.CDSEGMER)AND
        (FI.NRORG    = SE.NRORG)
      LEFT JOIN PARAVEND PA ON
        (FI.CDFILIAL = PA.CDFILIAL) AND
        (FI.NRORG    = PA.NRORG)
      LEFT JOIN ENDEFILI E ON
        (FI.CDFILIAL = E.CDFILIAL) AND
        (FI.NRORG    = E.NRORG   )
		WHERE
		  (FI.CDFILIAL = :P_CDFILIAL) AND
      (FI.NRORG    = :P_NRORG   )		  
		ORDER BY
		   FI.CDFILIAL
	";
	
	const INSERT_TABEPREC = "
  	INSERT INTO TABEPREC
  		(CDFILIAL,CDTABEPREC,NMTABEPREC,IDATIVO,CDOPERULTATU,DTULTATU,
      NRORGULTATU,CDOPERINCLUSAO,DTINCLUSAO,NRORG,NRORGINCLUSAO)
    VALUES
      (:CDFILIAL,:CDTABEPREC,:NMTABEPREC,:IDATIVO,:CDOPERULTATU,:DTULTATU,
      :NRORGULTATU,:CDOPERINCLUSAO,:DTINCLUSAO,:NRORG,:NRORGINCLUSAO)
  ";
  
    const UPDATE_TABEPREC = "
      UPDATE TABEPREC 
        SET CDOPERULTATU = :CDOPERULTATU,
            DTULTATU = SYSDATE,
            NRORGULTATU = :NRORGULTATU,
            NMTABEPREC =:NMTABEPREC
      WHERE CDTABEPREC = :CDTABEPREC AND 
            NRORG = :NRORG AND 
            CDFILIAL = :CDFILIAL";
  
  const INSERT_ITEMPRECO = "
    INSERT INTO ITEMPRECO
      (CDFILIAL,CDTABEPREC,DTINIVGPREC,CDPRODUTO,VRPRECITEM,VRCUSTITEM,VRPRESUGITEM,
      IDPRECVARIA,VRPRECITEMCL,IDPRODPROMOC,CDPRPAITABPR,IDATIVO,CDOPERULTATU,DTULTATU,
      NRORGULTATU,CDOPERINCLUSAO,DTINCLUSAO,NRORG,NRORGINCLUSAO, HRFIMVENPROD, HRINIVENPROD, VRPRECITEMCMD, VRPRECITEMDLV)
    VALUES
      (:CDFILIAL,:CDTABEPREC,:DTINIVGPREC,:CDPRODUTO,:VRPRECITEM,:VRCUSTITEM,:VRPRESUGITEM,
      :IDPRECVARIA,:VRPRECITEMCL,:IDPRODPROMOC,:CDPRPAITABPR,:IDATIVO,:CDOPERULTATU,:DTULTATU,
      :NRORGULTATU,:CDOPERINCLUSAO,:DTINCLUSAO,:NRORG,:NRORGINCLUSAO, :HRFIMVENPROD, :HRINIVENPROD, :VRPRECITEMCMD, :VRPRECITEMDLV)
	";
	
	const INSERT_VIGENCIA = "
  INSERT INTO TABEVEND (CDFILIAL,CDTABEPREC,DTINIVGPREC,DTFINVGPREC,CDOPERINCLUSAO,DTINCLUSAO,NRORGINCLUSAO,NRORG,CDOPERULTATU,DTULTATU,NRORGULTATU) VALUES
  (:CDFILIAL, :CDTABEPREC, :DTINIVGPREC, :DTFINVGPREC, :CDOPERINCLUSAO, :DTINCLUSAO, :NRORGINCLUSAO, :NRORG, :CDOPERULTATU, :DTULTATU, :NRORGULTATU)
	";
	
	const UPDATE_VIGENCIA = "
      UPDATE TABEVEND 
        SET DTFINVGPREC = :DTFINVGPREC,
            CDOPERULTATU = :CDOPERULTATU,
            DTULTATU = :DTULTATU,
            NRORGULTATU = :NRORGULTATU
      WHERE DTINIVGPREC = :OLD_DTINIVGPREC AND
            DTFINVGPREC = :OLD_DTFINVGPREC AND
            CDFILIAL = :CDFILIAL AND  
            CDTABEPREC = :CDTABEPREC AND 
            NRORG = :NRORG";
    
    const DELETE_TABEVEND = "
  	DELETE FROM TABEVEND
  	 WHERE CDFILIAL		  = :CDFILIAL
  	   AND DTINIVGPREC	= :DTINIVGPREC
  	   AND CDTABEPREC	  = :CDTABEPREC
  	   AND NRORG	      = :NRORG
  ";
  
  const UPDATE_ITEMPRECO = "
    UPDATE ITEMPRECO SET
      VRPRECITEM   = :VRPRECITEM,
      VRCUSTITEM   = :VRCUSTITEM,
      VRPRESUGITEM = :VRPRESUGITEM,
      IDPRECVARIA  = :IDPRECVARIA,
      VRPRECITEMCL = :VRPRECITEMCL,
      IDPRODPROMOC = :IDPRODPROMOC,
      CDPRPAITABPR = :CDPRPAITABPR,
      HRINIVENPROD = :HRINIVENPROD,
      HRFIMVENPROD = :HRFIMVENPROD,
      VRPRECITEMDLV = :VRPRECITEMDLV,
      VRPRECITEMCMD = :VRPRECITEMCMD
    
    WHERE CDFILIAL     = :CDFILIAL 
      AND CDPRODUTO    = :CDPRODUTO
      AND CDTABEPREC   = :CDTABEPREC 
      AND DTINIVGPREC  = :DTINIVGPREC
      AND NRORG        = :NRORG";
      
      const UPDATE_ITEMPRECO_INLINE = "
    UPDATE ITEMPRECO SET
      VRPRECITEM    = :VRPRECITEM,
      VRCUSTITEM    = :VRCUSTITEM,
      VRPRESUGITEM  = :VRPRESUGITEM,
      VRPRECITEMCL  = :VRPRECITEMCL,
      IDPRODPROMOC  = :IDPRODPROMOC,
      HRINIVENPROD  = :HRINIVENPROD,
      HRFIMVENPROD  = :HRFIMVENPROD,
      VRPRECITEMDLV = :VRPRECITEMDLV,
      VRPRECITEMCMD = :VRPRECITEMCMD,
      IDPRECVARIA   = :IDPRECVARIA
    
    WHERE CDFILIAL     = :CDFILIAL 
      AND CDPRODUTO    = :CDPRODUTO
      AND CDTABEPREC   = :CDTABEPREC 
      AND DTINIVGPREC  = :DTINIVGPREC
      AND NRORG        = :NRORG";
      
      const GET_VALID_INSERT_VIGDATE = "
  SELECT DTINIVGPREC AS INICIO,
         DTFINVGPREC AS FIM
  FROM TABEVEND
  
  WHERE CDFILIAL = :CDFILIAL
    AND CDTABEPREC = :CDTABEPREC
    
  UNION ALL
    
  SELECT MIN(DTINIVGPREC) AS INICIO,
         MAX(DTFINVGPREC) AS FIM
    FROM TABEVEND 
  WHERE CDFILIAL = :CDFILIAL
    AND CDTABEPREC = :CDTABEPREC";
    
    const UPDATE_PRECODIFERENCIADO = "
  UPDATE ITEMPRECODIA 
    SET VRPRECODIA      = :VRPRECODIA,
        DTFINVALPREC    = :DTFINVALPREC,
        IDPERVALORPR    = :IDPERVALORPR,
        IDDESCACREPR    = :IDDESCACREPR,
        HRFINPRECDIA    = :HRFINPRECDIA,
        IDVISUACUPOM    = :IDVISUACUPOM,
        CDOPERULTATU    = :CDOPERULTATU,
        DTULTATU        = :DTULTATU,
        VRPRECODIF      = :VRPRECODIF,
        NRORGULTATU     = :NRORGULTATU,
        VRPRECODIADLV   = :VRPRECODIADLV,
        VRPRECODIACMD   = :VRPRECODIACMD,
        IDTPMODGERAL    = :IDTPMODGERAL,
        IDTPMODDLV      = :IDTPMODDLV,
        IDTPMODCMD      = :IDTPMODCMD
        
    WHERE CDFILIAL      = :CDFILIAL      AND
          CDTABEPREC    = :CDTABEPREC    AND
          DTINIVGPREC   = :DTINIVGPREC   AND
          CDPRODUTO     = :CDPRODUTO     AND
          CDPRPAITABPR  = :CDPRPAITABPR  AND
          NRDIASEMANPR  = :NRDIASEMANPR  AND
          HRINIPRECDIA  = :HRINIPRECDIA  AND
          DTINIVALPREC  = :DTINIVALPREC  AND
          CDTIPOCONSPD  = :CDTIPOCONSPD  AND
          NRORG         = :NRORG
	";
	
	const GET_VALID_UPDATE_VIGDATE = "
    SELECT DTINIVGPREC AS INICIO,
           DTFINVGPREC AS FIM
      FROM TABEVEND
      WHERE CDFILIAL = :CDFILIAL
        AND CDTABEPREC = :CDTABEPREC
        AND DTINIVGPREC <> :DTINIVGPREC
        AND DTFINVGPREC <> :DTFINVGPREC
    
    UNION ALL
    
    SELECT * FROM
      (SELECT MIN(DTINIVGPREC) AS INICIO,
              MAX(DTFINVGPREC) AS FIM
      FROM TABEVEND
      WHERE CDFILIAL = :CDFILIAL
        AND CDTABEPREC = :CDTABEPREC)
    
    WHERE INICIO <> :DTINIVGPREC
          AND FIM <> :DTFINVGPREC
	";
	
	const IS_PARAMETERIZED_BY_CLIENTEFILIAL = "
    SELECT CDFILIAL
    FROM CLIENFILIAL
    WHERE (CDCFILTABPRE = :CDFILIAL)
    AND (CDTABEPREC = :CDTABEPREC)";
  
  const IS_PARAMETERIZED_BY_LOJA = "
  SELECT CDLOJA
    FROM LOJA
  WHERE (CDFILIAL = :CDFILIAL)
  AND (CDTABEPREC = :CDTABEPREC)";
  
	const IS_PARAMETERIZED_BY_FILIAL = "
  SELECT CDFILIAL
  FROM PARAVEND
  WHERE (CDFILIAL = :CDFILIAL)
  AND (CDTABEPREC = :CDTABEPREC)";
  
  
	const IS_PARAMETERIZED_BY_CLIENTE = "
  SELECT CDCLIENTE
  FROM CLIENTE
  WHERE (CDFILTABPREC = :CDFILIAL)
  AND (CDTABEPREC = :CDTABEPREC)";
  
  const UPDATE_ITEMPRECO_INLINE_PRECODIFERENCIADO = "
      UPDATE ITEMPRECODIA
      SET VRPRECODIA = :VRPRECODIA,
        VRPRECODIADLV   = :VRPRECODIADLV,
        VRPRECODIACMD   = :VRPRECODIACMD
      WHERE CDFILIAL = :CDFILIAL
        AND CDTABEPREC = :CDTABEPREC
        AND DTINIVGPREC = :DTINIVGPREC
        AND CDPRODUTO = :CDPRODUTO
        AND CDPRPAITABPR = :CDPRPAITABPR
        AND NRDIASEMANPR = :NRDIASEMANPR
        AND HRINIPRECDIA = :HRINIPRECDIA
        AND CDTIPOCONSPD = :CDTIPOCONSPD
        AND NRORG = :NRORG
        
  ";
  
  const updItemPrecoAtuPrec = "
    UPDATE ITEMPRECO
    SET
       VRPRECITEM   = NVL(VRPRECITEM,0) + NVL(VRCUSTITEM,0) - (NVL(VRPRECITEM,0) + NVL(VRPRECITEMCL,0)),
       VRPRECMAXITE = NVL(VRPRECITEM,0) + NVL(VRCUSTITEM,0) - (NVL(VRPRECITEM,0) + NVL(VRPRECITEMCL,0))
    WHERE
       (CDFILIAL     = :CDFILIAL   ) AND
       (CDTABEPREC   = :CDTABEPREC ) AND
       (DTINIVGPREC  = :DTINIVGPREC) AND
       (VRCUSTITEM   <> 0          )
  ";
  
  const GET_INTERVALO_CAD_AUTOMATICO = "
    SELECT CDPRODUTO FROM ITEMPRECO WHERE CDTABEPREC = :CDTABEPREC AND CDFILIAL = :CDFILIAL AND NRORG = :NRORG AND DTINIVGPREC = :DTINIVGPREC AND (CDPRODUTO BETWEEN :CDPRODUTOINI AND :CDPRODUTOFIN)
  ";
  
  const SET_PRECO_AUTOMATICO = "
    UPDATE ITEMPRECO SET VRPRECITEM = :VRPRECITEM WHERE CDTABEPREC = :CDTABEPREC AND CDFILIAL = :CDFILIAL AND NRORG = :NRORG AND CDPRODUTO = :CDPRODUTO AND DTINIVGPREC = :DTINIVGPREC
  ";
  
  const SELECT_PRECODIFERENCIADO = "
    SELECT
        COUNT(*) AS TOT
    FROM
        ITEMPRECODIA
    WHERE
        CDFILIAL            = :CDFILIAL
        AND CDTABEPREC      = :CDTABEPREC
        AND DTINIVGPREC     = :DTINIVGPREC
        AND CDPRODUTO       = :CDPRODUTO
        AND CDPRPAITABPR    = :CDPRPAITABPR
        AND NRDIASEMANPR    = :NRDIASEMANPR
        AND HRINIPRECDIA    = :HRINIPRECDIA
        AND DTINIVALPREC    = :DTINIVALPREC
        AND CDTIPOCONSPD    = :CDTIPOCONSPD
        AND NRORG           = :NRORG
  ";
  
    const SELECT_PRECO_ANTIGO = "
    SELECT
        VRPRECITEM
    FROM
        ITEMPRECO
    WHERE
            CDTABEPREC = :CDTABEPREC
        AND CDPRODUTO = :CDPRODUTO
        AND CDFILIAL = :CDFILIAL
        AND NRORG = :NRORG
  ";
  
  	const INSERT_TABEULTPREC = "
  	INSERT INTO TABEULTPREC
  		(CDFILIAL,CDTABULTPREC,CDPRODUTO,VRPRODATUAL,VRPROTANT,DTALTERACAO,
      CDOPERADOR,NRORG,IDATIVO,DTINCLUSAO,DTULTATU,NRORGINCLUSAO,CDOPERINCLUSAO,NRORGULTATU,CDOPERULTATU)
    VALUES
      (:CDFILIAL,:CDTABEPREC,:CDPRODUTO,:PRECO,:VRPROTANT,:DTALTERACAO,
      :CDOPERADOR,:NRORG,'S',:INCLUSAODT,:DTULTATU,:NRORGINCLUSAO,:CDOPERINCLUSAO,:NRORGULTATU,:CDOPERULTATU)
  ";
  
    const UPDATE_PRECO_ITEM = "
      UPDATE ITEMPRECO 
        SET VRPRECITEM = :PRECO
      WHERE CDTABEPREC = :CDTABEPREC AND
            CDPRODUTO = :CDPRODUTO AND
            NRORG = :NRORG AND
            CDFILIAL = :CDFILIAL
    ";
    
    const SELECT_PRECO_PRODUTO = "
        SELECT VRPRECITEM
        FROM ITEMPRECO
        WHERE CDPRODUTO = :CDPRODUTO
            AND CDTABEPREC = :CDTABEPREC
            AND CDFILIAL = :CDFILIAL
            AND DTINIVGPREC = :DTINIVGPREC";
            
    const GET_VALORES_DIFERENCIADOS = "
        SELECT VRPRECODIA
            FROM ITEMPRECODIA
            WHERE CDPRODUTO = :CDPRODUTO
                AND CDFILIAL = :CDFILIAL
                AND CDTABEPREC = :CDTABEPREC
                AND IDDESCACREPR = 'D'
                AND NRORG = :NRORG
                AND IDPERVALORPR = 'V'
                AND DTINIVGPREC = :DTINIVGPREC";
}